==> voreen-src-4.0.1-win.zip: voreen-src-4.0.1-win/include/voreen/core/datastructures/roi/roisphere.h <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2012 University of Muenster, Germany.                        *
 * Visualization and Computer Graphics Group <http://viscg.uni-muenster.de>        *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#ifndef VRN_ROISPHERE_H
#define VRN_ROISPHERE_H

#include "voreen/core/datastructures/roi/roicube.h"

namespace voreen {

class ROISphere : public ROINormalizedGeometry {
public:
    ROISphere(Grid grid, tgt::vec3 center, tgt::vec3 dimensions);
    ROISphere(Grid grid, tgt::vec3 center, float radius);
    ROISphere();
    virtual std::string getClassName() const { return "ROISphere"; }
    virtual ROIBase* create() const { return new ROISphere(); }

    virtual bool inROINormalized(tgt::vec3 p) const;
    virtual MeshListGeometry* generateNormalizedMesh() const;
    virtual MeshListGeometry* generateNormalizedMesh(tgt::plane pl) const;
private:
    static const std::string loggerCat_;
};

} //namespace

#endif

==> voreen-src-4.2-win.zip: voreen-src-4.2-win/include/voreen/core/datastructures/roi/roisphere.h <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2013 University of Muenster, Germany.                        *
 * Visualization and Computer Graphics Group <http://viscg.uni-muenster.de>        *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#ifndef VRN_ROISPHERE_H
#define VRN_ROISPHERE_H

#include "voreen/core/datastructures/roi/roicube.h"

namespace voreen {

class ROISphere : public ROINormalizedGeometry {
public:
    ROISphere(Grid grid, tgt::vec3 center, tgt::vec3 dimensions);
    ROISphere(Grid grid, tgt::vec3 center, float radius);
    ROISphere();
    virtual std::string getClassName() const { return "ROISphere"; }
    virtual ROIBase* create() const { return new ROISphere(); }

    virtual bool inROINormalized(tgt::vec3 p) const;
    virtual Geometry* generateNormalizedMesh() const;
    virtual Geometry* generateNormalizedMesh(tgt::plane pl) const;
private:
    static const std::string loggerCat_;
};

} //namespace

#endif
